==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/General/converter/translations/converter_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="131"/>
        <location filename="../converter.cpp" line="231"/>
        <source>Cancelled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="146"/>
        <location filename="../converter.cpp" line="213"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="178"/>
        <source>Converting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="242"/>
        <source>Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="280"/>
        <source>Finished</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Audio Converter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="44"/>
        <source>Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="49"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Output directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="80"/>
        <source>Output file name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="97"/>
        <source>Preset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="114"/>
        <source>Overwrite existing files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="124"/>
        <source>Convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="131"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="107"/>
        <source>Choose a directory</source>
        <translation type="unfinished">Elija un directorio</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="190"/>
        <source>Artist</source>
        <translation type="unfinished">Intérprete</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="191"/>
        <source>Album</source>
        <translation type="unfinished">Album</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="192"/>
        <source>Album Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="39"/>
        <location filename="../converterdialog.cpp" line="193"/>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="194"/>
        <source>Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="195"/>
        <source>Two-digit Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="200"/>
        <source>Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="201"/>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="202"/>
        <source>File Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="196"/>
        <source>Genre</source>
        <translation type="unfinished">Género</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="128"/>
        <location filename="../converterdialog.cpp" line="367"/>
        <location filename="../converterdialog.cpp" line="373"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="133"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="197"/>
        <source>Comment</source>
        <translation type="unfinished">Comentario</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="198"/>
        <source>Composer</source>
        <translation type="unfinished">Compositor</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="199"/>
        <source>Duration</source>
        <translation type="unfinished">Duración</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="203"/>
        <source>Year</source>
        <translation type="unfinished">Año</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="204"/>
        <source>Condition</source>
        <translation type="unfinished">Condición</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="210"/>
        <source>Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="211"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="212"/>
        <source>Create a Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="213"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="367"/>
        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="373"/>
        <source>Process &quot;%1&quot; finished with error.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="30"/>
        <source>Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>About Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="52"/>
        <source>Qmmp Converter Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="53"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished">Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="33"/>
        <source>Convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="34"/>
        <source>Meta+C</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/General/converter/translations/converter_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>Converter</name>
    <message>
        <location filename="../converter.cpp" line="131"/>
        <location filename="../converter.cpp" line="231"/>
        <source>Cancelled</source>
        <translation>Cancelado</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="146"/>
        <location filename="../converter.cpp" line="213"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="181"/>
        <source>Converting</source>
        <translation>Convirtiendo</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="242"/>
        <source>Encoding</source>
        <translation>Codificando</translation>
    </message>
    <message>
        <location filename="../converter.cpp" line="280"/>
        <source>Finished</source>
        <translation>Finalizado</translation>
    </message>
</context>
<context>
    <name>ConverterDialog</name>
    <message>
        <location filename="../converterdialog.ui" line="14"/>
        <source>Audio Converter</source>
        <translation>Convertidor de Audio</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="44"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="49"/>
        <source>State</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="63"/>
        <source>Output directory:</source>
        <translation>Directorio de salida:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="80"/>
        <source>Output file name:</source>
        <translation>Nombre de archivo de salida:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="97"/>
        <source>Preset:</source>
        <translation>Pre-programado:</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="114"/>
        <source>Overwrite existing files</source>
        <translation>Sobre-escribir archivos existentes</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="124"/>
        <source>Convert</source>
        <translation>Convertir</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="131"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="108"/>
        <source>Choose a directory</source>
        <translation>Elija un directorio</translation>
    </message>
    <message>
        <location filename="../converterdialog.ui" line="39"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="198"/>
        <source>Create a Copy</source>
        <translation>Crear una copia</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="129"/>
        <location filename="../converterdialog.cpp" line="353"/>
        <location filename="../converterdialog.cpp" line="359"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="134"/>
        <source>Waiting</source>
        <translation>Esperando</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="196"/>
        <source>Create</source>
        <translation>Crear</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="197"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="199"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="353"/>
        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
        <translation>Incapaz de ejecutar &quot;%1&quot;. Programa no encontrado.</translation>
    </message>
    <message>
        <location filename="../converterdialog.cpp" line="359"/>
        <source>Process &quot;%1&quot; finished with error.</source>
        <translation>El proceso &quot;%1&quot; finalizó sin errores.</translation>
    </message>
</context>
<context>
    <name>ConverterFactory</name>
    <message>
        <location filename="../converterfactory.cpp" line="29"/>
        <source>Converter Plugin</source>
        <translation>Módulo Convertidor</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="50"/>
        <source>About Converter Plugin</source>
        <translation>Acerca del Módulo Convertidor</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="51"/>
        <source>Qmmp Converter Plugin</source>
        <translation>Módulo Convertidor de Qmmp</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="52"/>
        <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
        <translation>Este módulo convierte archivos de audio soportados hacia otros formatos utilizando codificadores externos de consola</translation>
    </message>
    <message>
        <location filename="../converterfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>ConverterHelper</name>
    <message>
        <location filename="../converterhelper.cpp" line="33"/>
        <source>Convert</source>
        <translation>Convertir</translation>
    </message>
    <message>
        <location filename="../converterhelper.cpp" line="34"/>
        <source>Meta+C</source>
        <translation>Meta+C</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Editor de preprogamados</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="29"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="35"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="45"/>
        <source>Extension:</source>
        <translation>Extensión:</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="58"/>
        <source>Command</source>
        <translation>Instrucción</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="77"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="83"/>
        <source>Write tags</source>
        <translation>Escribir etiquetas</translation>
    </message>
    <message>
        <location filename="../preseteditor.ui" line="90"/>
        <source>Convert to 16 bit</source>
        <translation>Convertir a 16 bit</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="37"/>
        <source>%1 (Read Only)</source>
        <translation>%1 (Sólo Lectura)</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="70"/>
        <source>Output file</source>
        <translation>Archivo de salida</translation>
    </message>
    <message>
        <location filename="../preseteditor.cpp" line="71"/>
        <source>Input file</source>
        <translation>Archivo de entrada</translation>
    </message>
</context>
</TS>
